@@ -22,24 +22,10 @@
 #include <stdlib.h>
 #include <gnome-xml/entities.h>
 
-/* Quick hack so I can mark strings */
-
-#ifdef _ 
-#warning "_ already defined"
-#else
-#define _(x) x
-#endif
-
-#ifdef N_ 
-#warning "N_ already defined"
-#else
-#define N_(x) x
-#endif
-
 static void
 entry_sync_if_needed(Entry* e, GConfValue* val);
 static GConfValue*
-node_extract_value(xmlNodePtr node, const gchar** locales, GConfError** err);
+node_extract_value(xmlNodePtr node, const gchar** locales, GError** err);
 static xmlNodePtr
 find_schema_subnode_by_locale(xmlNodePtr node, const gchar* locale);
 static void
@@ -80,7 +66,7 @@ entry_destroy (Entry* e)
     g_free(e->name);
 
   if (e->cached_value)
-    gconf_value_destroy(e->cached_value);
+    gconf_value_free(e->cached_value);
 
   if (e->mod_user)
     g_free(e->mod_user);
@@ -116,7 +102,7 @@ entry_get_node (Entry*e)
 }
 
 GConfValue*
-entry_get_value(Entry* e, const gchar** locales, GConfError** err)
+entry_get_value(Entry* e, const gchar** locales, GError** err)
 {
   const gchar* sl;
   
@@ -131,7 +117,7 @@ entry_get_value(Entry* e, const gchar** locales, GConfError** err)
 
   g_assert(e->cached_value->type == GCONF_VALUE_SCHEMA);
 
-  sl = gconf_schema_locale(gconf_value_schema(e->cached_value));
+  sl = gconf_schema_get_locale(gconf_value_get_schema(e->cached_value));
 
   /* optimize most common cases first */
   if (sl == NULL && (locales == NULL ||
@@ -144,7 +130,7 @@ entry_get_value(Entry* e, const gchar** locales, GConfError** err)
     {
       /* We want a locale other than the currently-loaded one */
       GConfValue* newval;
-      GConfError* error = NULL;
+      GError* error = NULL;
 
       entry_sync_if_needed(e, NULL);
       
@@ -152,7 +138,7 @@ entry_get_value(Entry* e, const gchar** locales, GConfError** err)
       if (newval != NULL)
         {
           /* We found a schema with an acceptable locale */
-          gconf_value_destroy(e->cached_value);
+          gconf_value_free(e->cached_value);
           e->cached_value = newval;
           g_return_val_if_fail(error == NULL, e->cached_value);
         }
@@ -160,8 +146,8 @@ entry_get_value(Entry* e, const gchar** locales, GConfError** err)
         {
           /* There was an error */
           gconf_log(GCL_WARNING, _("Ignoring XML node with name `%s': %s"),
-                    e->name, error->str);
-          gconf_error_destroy(error);
+                    e->name, error->message);
+          g_error_free(error);
 
           /* Fall back to currently-loaded thing if any */
         }
@@ -179,7 +165,7 @@ entry_set_value(Entry* e, GConfValue* value)
   entry_sync_if_needed(e, value);
   
   if (e->cached_value)
-    gconf_value_destroy(e->cached_value);
+    gconf_value_free(e->cached_value);
       
   e->cached_value = gconf_value_copy(value);
 
@@ -196,7 +182,7 @@ entry_unset_value     (Entry        *e,
     {
       if (locale && e->cached_value->type == GCONF_VALUE_SCHEMA)
         {
-          GConfError* error = NULL;
+          GError* error = NULL;
           
           /* Remove the localized node from the XML tree */
           g_assert(e->node != NULL);
@@ -205,13 +191,13 @@ entry_unset_value     (Entry        *e,
           /* e->cached_value is always non-NULL if some value is
              available; in the schema case there may be leftover
              values */
-          gconf_value_destroy(e->cached_value);
+          gconf_value_free(e->cached_value);
           e->cached_value = node_extract_value(e->node, NULL, &error);
 
           if (error != NULL)
             {
-              gconf_log(GCL_WARNING, _("%s"), error->str);
-              gconf_error_destroy(error);
+              gconf_log(GCL_WARNING, _("%s"), error->message);
+              g_error_free(error);
               error = NULL;
             }
         }
@@ -219,12 +205,12 @@ entry_unset_value     (Entry        *e,
         {
           /* if locale == NULL nuke all the locales */
           if (e->cached_value)
-            gconf_value_destroy(e->cached_value);
+            gconf_value_free(e->cached_value);
           e->cached_value = NULL;
         }
       else
         {
-          gconf_value_destroy(e->cached_value);
+          gconf_value_free(e->cached_value);
           e->cached_value = NULL;
         }
 
@@ -319,7 +305,7 @@ void
 entry_fill_from_node(Entry* e)
 {
   gchar* tmp;
-  GConfError* error = NULL;
+  GError* error = NULL;
 
   g_return_if_fail(e->node != NULL);
   
@@ -368,7 +354,7 @@ entry_fill_from_node(Entry* e)
   entry_sync_if_needed(e, NULL);
   
   if (e->cached_value != NULL)
-    gconf_value_destroy(e->cached_value);
+    gconf_value_free(e->cached_value);
   
   e->cached_value = node_extract_value(e->node, NULL, /* FIXME current locale as a guess */
                                        &error);
@@ -384,8 +370,8 @@ entry_fill_from_node(Entry* e)
        * we improperly log an error here
        */
       gconf_log(GCL_WARNING, _("Ignoring XML node `%s', except for possible schema name: %s"),
-                e->name, error->str);
-      gconf_error_destroy(error);
+                e->name, error->message);
+      g_error_free(error);
     }
 }
 
@@ -451,7 +437,7 @@ node_set_schema_value(xmlNodePtr node,
   const gchar* type;
   xmlNodePtr found = NULL;
 
-  sc = gconf_value_schema(value);
+  sc = gconf_value_get_schema(value);
 
   /* Set the types */
   if (sc->list_type != GCONF_VALUE_INVALID)
@@ -480,7 +466,7 @@ node_set_schema_value(xmlNodePtr node,
   my_xmlSetProp(node, "stype", gconf_value_type_to_string(sc->type));
   my_xmlSetProp(node, "owner", sc->owner);
 
-  locale = gconf_schema_locale(sc);
+  locale = gconf_schema_get_locale(sc);
 
   gconf_log(GCL_DEBUG, "Setting XML node to schema with locale `%s'",
             locale);
@@ -550,7 +536,7 @@ node_set_value(xmlNodePtr node, GConfValue* value)
         free_childs(node);
 
         encoded = xmlEncodeEntitiesReentrant(node->doc,
-                                             gconf_value_string(value));
+                                             gconf_value_get_string(value));
         
         child = xmlNewChild(node, NULL, "stringvalue",
                             encoded);
@@ -569,10 +555,10 @@ node_set_value(xmlNodePtr node, GConfValue* value)
         free_childs(node);
 
         my_xmlSetProp(node, "ltype",
-                      gconf_value_type_to_string(gconf_value_list_type(value)));
+                      gconf_value_type_to_string(gconf_value_get_list_type(value)));
         
         /* Add a new child for each node */
-        list = gconf_value_list(value);
+        list = gconf_value_get_list(value);
 
         while (list != NULL)
           {
@@ -598,11 +584,11 @@ node_set_value(xmlNodePtr node, GConfValue* value)
         car = xmlNewChild(node, NULL, "car", NULL);
         cdr = xmlNewChild(node, NULL, "cdr", NULL);
 
-        g_return_if_fail(gconf_value_car(value) != NULL);
-        g_return_if_fail(gconf_value_cdr(value) != NULL);
+        g_return_if_fail(gconf_value_get_car(value) != NULL);
+        g_return_if_fail(gconf_value_get_cdr(value) != NULL);
         
-        node_set_value(car, gconf_value_car(value));
-        node_set_value(cdr, gconf_value_cdr(value));
+        node_set_value(car, gconf_value_get_car(value));
+        node_set_value(cdr, gconf_value_get_cdr(value));
       }
       break;
       
@@ -692,7 +678,7 @@ schema_subnode_extract_data(xmlNodePtr node, GConfSchema* sc)
 {
   gchar* sd_str;
   gchar* locale_str;
-  GConfError* error = NULL;
+  GError* error = NULL;
   
   sd_str = my_xmlGetProp(node, "short_desc");
   locale_str = my_xmlGetProp(node, "locale");
@@ -733,8 +719,8 @@ schema_subnode_extract_data(xmlNodePtr node, GConfSchema* sc)
                       g_assert(default_value == NULL);
                       
                       gconf_log(GCL_WARNING, _("Failed reading default value for schema: %s"), 
-                                error->str);
-                      gconf_error_destroy(error);
+                                error->message);
+                      g_error_free(error);
                       error = NULL;
                       
                       bad_nodes = g_slist_prepend(bad_nodes, iter);
@@ -926,7 +912,7 @@ schema_node_extract_value(xmlNodePtr node, const gchar** locales)
    <default> node
 */
 static GConfValue*
-node_extract_value(xmlNodePtr node, const gchar** locales, GConfError** err)
+node_extract_value(xmlNodePtr node, const gchar** locales, GError** err)
 {
   GConfValue* value = NULL;
   gchar* type_str;
@@ -1076,9 +1062,9 @@ node_extract_value(xmlNodePtr node, const gchar** locales, GConfError** err)
                           {
                             gconf_log(GCL_WARNING,
                                       _("Bad XML node: %s"),
-                                      (*err)->str);
+                                      (*err)->message);
                             /* avoid pile-ups */
-                            gconf_clear_error(err);
+                            g_clear_error(err);
                           }
                       }
                     else if (v->type != list_type)
@@ -1086,7 +1072,7 @@ node_extract_value(xmlNodePtr node, const gchar** locales, GConfError** err)
                         gconf_log(GCL_WARNING, _("List contains a badly-typed node (%s, should be %s)"),
                                   gconf_value_type_to_string(v->type),
                                   gconf_value_type_to_string(list_type));
-                        gconf_value_destroy(v);
+                        gconf_value_free(v);
                         v = NULL;
                       }
                   }
@@ -1136,16 +1122,16 @@ node_extract_value(xmlNodePtr node, const gchar** locales, GConfError** err)
                           {
                             gconf_log(GCL_WARNING,
                                       _("Ignoring bad car from XML pair: %s"),
-                                      (*err)->str);
+                                      (*err)->message);
                             /* prevent pile-ups */
-                            gconf_clear_error(err);
+                            g_clear_error(err);
                           }
                       }
                     else if (car->type == GCONF_VALUE_LIST ||
                              car->type == GCONF_VALUE_PAIR)
                       {
                         gconf_log(GCL_WARNING, _("parsing XML file: lists and pairs may not be placed inside a pair"));
-                        gconf_value_destroy(car);
+                        gconf_value_free(car);
                         car = NULL;
                       }
                   }
@@ -1158,9 +1144,9 @@ node_extract_value(xmlNodePtr node, const gchar** locales, GConfError** err)
                           {
                             gconf_log(GCL_WARNING,
                                       _("Ignoring bad cdr from XML pair: %s"),
-                                      (*err)->str);
+                                      (*err)->message);
                             /* avoid pile-ups */
-                            gconf_clear_error(err);
+                            g_clear_error(err);
                           }
                       }
                     else if (cdr->type == GCONF_VALUE_LIST ||
@@ -1168,7 +1154,7 @@ node_extract_value(xmlNodePtr node, const gchar** locales, GConfError** err)
                       {
                         gconf_log(GCL_WARNING,
                                   _("parsing XML file: lists and pairs may not be placed inside a pair"));
-                        gconf_value_destroy(cdr);
+                        gconf_value_free(cdr);
                         cdr = NULL;
                       }
                   }
@@ -1198,14 +1184,14 @@ node_extract_value(xmlNodePtr node, const gchar** locales, GConfError** err)
             if (car)
               {
                 g_assert(cdr == NULL);
-                gconf_value_destroy(car);
+                gconf_value_free(car);
                 gconf_set_error(err, GCONF_ERROR_PARSE_ERROR,
                                 _("Missing cdr from pair of values in XML file"));
               }
             else if (cdr)
               {
                 g_assert(car == NULL);
-                gconf_value_destroy(cdr);
+                gconf_value_free(cdr);
                 gconf_set_error(err, GCONF_ERROR_PARSE_ERROR,
                                 _("Missing car from pair of values in XML file"));
               }
